OC.L10N.register(
    "core",
    {
    "Please select a file." : "Hãy chọn một tệp.",
    "File is too big" : "Tệp quá lớn",
    "The selected file is not an image." : "Tệp tin được chọn không phải là ảnh.",
    "The selected file cannot be read." : "Tệp tin được chọn không thể đọc.",
    "Invalid file provided" : "File không hợp lệ",
    "No image or file provided" : "Không có hình ảnh hoặc tập tin được cung cấp",
    "Unknown filetype" : "Không biết kiểu tập tin",
    "Invalid image" : "Hình ảnh không hợp lệ",
    "An error occurred. Please contact your admin." : "Có lỗi xảy ra. Vui lòng báo cho quản trị viên.",
    "No temporary profile picture available, try again" : "Ảnh cá nhân tạm thời không có giá trị, hãy thử lại",
    "No crop data provided" : "Không có dữ liệu nguồn được cung cấp",
    "No valid crop data provided" : "Dữ liệu trích xuất không hợp lệ",
    "Crop is not square" : "Trích xuất không chuẩn",
    "State token does not match" : "Mã trạng thái không khớp",
    "Password reset is disabled" : "Đã tắt chức năng đặt lại mật khẩu",
    "Couldn't reset password because the token is invalid" : "Không thể thiết lập lại mật khẩu do token không hợp lệ",
    "Couldn't reset password because the token is expired" : "Không thể thiết lập lại mật khẩu do token hết hạn",
    "%s password reset" : "%s thiết lập lại mật khẩu",
    "Password reset" : "Đặt lại mật khẩu",
    "Click the following button to reset your password. If you have not requested the password reset, then ignore this email." : "Nhấp vào nút sau để đặt lại mật khẩu. Nếu bạn không yêu cầu đặt lại mật khẩu, hãy bỏ qua email này.",
    "Click the following link to reset your password. If you have not requested the password reset, then ignore this email." : "Nhấp vào liên kết sau để đặt lại mật khẩu của bạn. Nếu bạn không yêu cầu đặt lại mật khẩu, hãy bỏ qua email này.",
    "Reset your password" : "Đổi mật khẩu",
    "Preparing update" : "Đang chuẩn bị cập nhật",
    "[%d / %d]: %s" : "[%d / %d]: %s",
    "Please use the command line updater because automatic updating is disabled in the config.php." : "Xin vui lòng sử dụng câu lệnh cập nhật bằng dòng lệnh do cập nhật tự động bị vô hiệu hóa trong file config.php",
    "[%d / %d]: Checking table %s" : "[%d / %d]: đang kiểm tra bảng được %s",
    "Turned on maintenance mode" : "Bật chế độ bảo trì",
    "Turned off maintenance mode" : "Tắt chế độ bảo trì",
    "Maintenance mode is kept active" : "Chế độ bảo trì đang được kích hoạt",
    "Updating database schema" : "Đang cập nhật lược đồ cơ sở dữ liệu",
    "Updated database" : "Cơ sở dữ liệu đã được cập nhật",
    "Checking whether the database schema can be updated (this can take a long time depending on the database size)" : "Đang kiểm tra xem lược đồ cơ sở dữ liệu có thể được cập nhật hay không (việc này có thể mất nhiều thời gian do phụ thuộc vào kích cỡ của cơ sở dữ liệu)",
    "Checked database schema update" : "Cập nhật lược đồ cơ sở dữ liệu đã được kiểm tra",
    "Checking updates of apps" : "Đang kiểm tra các bản cập nhật của các ứng dụng",
    "Checking for update of app \"%s\" in appstore" : "Đang kiểm tra cập nhật của ứng dụng %s trong appstore ",
    "Update app \"%s\" from appstore" : "Cập nhật ứng dụng \"%s\" từ appstore",
    "Checked for update of app \"%s\" in appstore" : "Đã kiểm tra bản cập nhật của ứng dụng \"%s\" trong kho ứng dụng",
    "Checking whether the database schema for %s can be updated (this can take a long time depending on the database size)" : "Đang kiểm tra liệu lược đồ cơ sở dữ liệu đối với %s có thể được cập nhật hay không (việc này có thể mất nhiều thời gian phụ thuộc vào kích cỡ của cơ sở dữ liệu)",
    "Checked database schema update for apps" : "Bản cập nhật lược đồ cơ sở dữ liệu cho các ứng dụng đã được kiểm tra",
    "Set log level to debug" : "Thiết lập cấp độ ghi nhật ký để gỡ rối",
    "Reset log level" : "Thiế lập lại cấp độ ghi nhật ký hệ thống",
    "Starting code integrity check" : "Bắt đầu mã kiểm tra sự toàn vẹn",
    "Finished code integrity check" : "Kết thúc mã kiểm tra sự toàn vẹn",
    "%s (incompatible)" : "%s (không tương thích)",
    "Following apps have been disabled: %s" : "Các ứng dụng sau bị vô hiệu hóa: %s",
    "Already up to date" : "Đã được cập nhật bản mới nhất",
    "Very weak password" : "Mật khẩu rất yếu",
    "Weak password" : "Mật khẩu yếu",
    "So-so password" : "Mật khẩu tạm được",
    "Good password" : "Mật khẩu tốt",
    "Strong password" : "Mật khẩu mạnh",
    "Error occurred while checking server setup" : "Có lỗi xảy ra khi kiểm tra thiết lập máy chủ",
    "Non-existing tag #{tag}" : "Thẻ không tồn tại # {tag}",
    "restricted" : "hạn chế",
    "invisible" : "không thể nhìn thấy.",
    "({scope})" : "({scope})",
    "Delete" : "Xóa",
    "Rename" : "Sửa tên",
    "Collaborative tags" : "Thẻ cộng tác",
    "No tags found" : "Không tìm thấy thẻ",
    "unknown text" : "văn bản không rõ",
    "Hello world!" : "Hello world!",
    "sunny" : "nắng",
    "Hello {name}, the weather is {weather}" : "Xin chào {name}, thời tiết hiện nay {weather}",
    "Hello {name}" : "Xin chào {name}",
    "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>Đây là kết quả tìm kiếm của bạn<script>cảnh báo (1)</script></strong>",
    "new" : "mới",
    "_download %n file_::_download %n files_" : ["tải về%ntệp"],
    "The update is in progress, leaving this page might interrupt the process in some environments." : "Quá trình cập nhật đang được tiến hành, đóng trang này có thể làm gián đoạn quá trình.",
    "Update to {version}" : "Cập nhật lên {version}",
    "An error occurred." : "Đã xảy ra lỗi.",
    "Please reload the page." : "Vui lòng tải lại trang.",
    "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "Quá trình cập nhật không thành công. Để biết thêm thông tin chi tiết <a href=\"{url}\">đề nghị xem các bài viết trong diễn đàn </a> để xử lý vấn đề này.",
    "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "Quá trình cập nhật không thành công. Xin vui lòng báo lại vấn đề gặp phải trong tới  <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Cộng đồng Nextcloud</a>.",
    "Continue to Nextcloud" : "Tiếp tục đến Nextcloud",
    "_The update was successful. Redirecting you to Nextcloud in %n second._::_The update was successful. Redirecting you to Nextcloud in %n seconds._" : ["Cập nhật thành công. Đang chuyển hướng bạn tới Nextcloud trong %ngiây."],
    "Searching other places" : "Tìm kiếm các nơi khác",
    "No search results in other folders for {tag}{filter}{endtag}" : "Không có kết quả tìm kiếm trong các thư mục khác cho {tag} {filter} {endtag}",
    "_{count} search result in another folder_::_{count} search results in other folders_" : ["{count} kết quả tìm kiếm trong các thư mục khác"],
    "Server side authentication failed!" : "Xác thực phía máy chủ không thành công!",
    "Please contact your administrator." : "Vui lòng liên hệ với quản trị viên.",
    "An internal error occurred." : "Đã xảy ra một lỗi nội bộ.",
    "Please try again or contact your administrator." : "Vui lòng thử lại hoặc liên hệ quản trị của bạn.",
    "Username or email" : "Tên truy cập hoặc email",
    "Password" : "Mật khẩu",
    "Log in" : "Đăng nhập",
    "Logging in …" : "Đang đăng nhập",
    "User disabled" : "Vô hiệu hóa sử dụng",
    "Reset password" : "Khôi phục mật khẩu",
    "Couldn't send reset email. Please contact your administrator." : "Không thể gửi thư điện tử yêu cầu thiết lập lại. Xin vui lòng liên hệ quản trị hệ thống",
    "Password can not be changed. Please contact your administrator." : "Không thể thay đổi được mật khẩu. Xin vui lòng liên hệ người quản trị hệ thống.",
    "Back to login" : "Quay lại trang đăng nhập",
    "New password" : "Mật khẩu mới",
    "I know what I'm doing" : "Tôi biết tôi đang làm gì",
    "Cancel" : "Hủy",
    "Forgot password?" : "Quên mật khẩu sao?",
    "Settings" : "Cài đặt",
    "Could not load your contacts" : "Không thể tải liên hệ của bạn",
    "Search contacts …" : "Tìm liên hệ ...",
    "No contacts found" : "Không tìm thấy liên hệ nào",
    "Show all contacts …" : "Hiển thị tất cả liên hệ…",
    "Loading your contacts …" : "Đang tải liên hệ của bạn ...",
    "Looking for {term} …" : "Đang tìm kiếm {term} ...",
    "No" : "Không",
    "Yes" : "Có",
    "No files in here" : "Không có file nào ở đây",
    "New folder" : "Tạo thư mục",
    "Name" : "Tên",
    "Size" : "Kích cỡ",
    "Modified" : "Thay đổi",
    "{newName} already exists" : "{newName} đã có",
    "Choose" : "Chọn",
    "Copy" : "Sao chép",
    "Move" : "Chuyển",
    "Error loading file picker template: {error}" : "Lỗi khi tải mẫu tập tin picker: {error}",
    "OK" : "Đồng ý",
    "Error loading message template: {error}" : "Lỗi khi tải mẫu thông điệp: {error}",
    "read-only" : "Chỉ đọc",
    "_{count} file conflict_::_{count} file conflicts_" : ["{count} tập tin xung đột"],
    "One file conflict" : "Một tập tin xung đột",
    "New Files" : "File mới",
    "Already existing files" : "Các file đang tồn tại",
    "Which files do you want to keep?" : "Bạn muốn tiếp tục với những tập tin nào?",
    "If you select both versions, the copied file will have a number added to its name." : "Nếu bạn chọn cả hai phiên bản, tập tin được sao chép sẽ được đánh thêm số vào tên của nó.",
    "Continue" : "Tiếp tục",
    "(all selected)" : "(Tất cả các lựa chọn)",
    "({count} selected)" : "({count} được chọn)",
    "Error loading file exists template" : "Lỗi khi tải tập tin mẫu đã tồn tại",
    "Pending" : "Đang chờ được phê duyệt",
    "Copy to {folder}" : "Sao chép tới thư mục {folder}",
    "Move to {folder}" : "Chuyển tới thư mục {folder}",
    "Saving..." : "Đang lưu...",
    "Authentication required" : "Cần phải được xác thực",
    "This action requires you to confirm your password" : "Để thực hiện hành động này, yêu cầu bạn phải nhập lại mật khẩu",
    "Confirm" : "Xác nhận",
    "Failed to authenticate, try again" : "Không thể xác thực thành công, xin vui lòng thử lại",
    "seconds ago" : "vài giây trước",
    "Connection to server lost" : "Kết nối tới máy chủ bị mất",
    "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["Xảy ra lỗi khi tải trang, tải lại trong %n giây"],
    "No action available" : "Không có hành động nào",
    "Error fetching contact actions" : "Lỗi khi nạp liên hệ",
    "Personal" : "Cá nhân",
    "Users" : "Người dùng",
    "Apps" : "Ứng dụng",
    "Admin" : "Quản trị",
    "Help" : "Giúp đỡ",
    "Access forbidden" : "Truy cập bị cấm",
    "File not found" : "Không tìm thấy tệp tin",
    "Error" : "Lỗi",
    "Internal Server Error" : "Lỗi máy chủ.",
    "The server was unable to complete your request." : "Máy chủ không thể hoàn thành được yêu cầu của bạn",
    "If this happens again, please send the technical details below to the server administrator." : "Nếu điều này tiếp tục xảy ra, xin vui lòng gửi thông tin kỹ thuật chi tiết tới người quản trị hệ thống.",
    "More details can be found in the server log." : "Các chi tiết có thể được tìm thấy trong nhật ký máy chủ.",
    "Technical details" : "Chi tiết kỹ thuật",
    "Remote Address: %s" : "Địa chỉ bên ngoài: %s",
    "Request ID: %s" : "Yêu cầu ID:%s",
    "Type: %s" : "Loại: %s",
    "Code: %s" : "Mã: %s",
    "Message: %s" : "Thông điệp:%s",
    "File: %s" : "Tệp: %s",
    "Line: %s" : "Dòng: %s",
    "Trace" : "Theo dõi",
    "Security warning" : "Cảnh báo bảo mật",
    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Thư mục và file dữ liệu của bạn có thể được truy cập từ internet bởi vì file .htaccess không hoạt động",
    "Create an <strong>admin account</strong>" : "Tạo một <strong>tài khoản quản trị</strong>",
    "Username" : "Tên đăng nhập",
    "Storage & database" : "Lưu trữ & cơ sở dữ liệu",
    "Data folder" : "Thư mục dữ liệu",
    "Configure the database" : "Cấu hình cơ sở dữ liệu",
    "Only %s is available." : "Chỉ %s khả dụng.",
    "Install and activate additional PHP modules to choose other database types." : "Cài đặt và kích hoạt các mô-đun PHP bổ sung để chọn các loại cơ sở dữ liệu khác.",
    "For more details check out the documentation." : "Để biết thêm chi tiết, hãy kiểm tra tài liệu.",
    "Database user" : "Người dùng cơ sở dữ liệu",
    "Database password" : "Mật khẩu cơ sở dữ liệu",
    "Database name" : "Tên cơ sở dữ liệu",
    "Database tablespace" : "Cơ sở dữ liệu tablespace",
    "Database host" : "Database host",
    "Please specify the port number along with the host name (e.g., localhost:5432)." : "Vui lòng xác định số cổng cùng với tên máy chủ lưu trữ (ví dụ: localhost: 5432).",
    "Performance warning" : "Cảnh báo hiệu suất",
    "Finish setup" : "Cài đặt hoàn tất",
    "Finishing …" : "Đang hoàn thành ...",
    "Need help?" : "Cần hỗ trợ ?",
    "See the documentation" : "Xem tài liệu",
    "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "Ứng dụng này yêu cầu JavaScript để hoạt động chính xác. Vui lòng {linkstart} bật JavaScript {linkend} và tải lại trang.",
    "More apps" : "Thêm ứng dụng",
    "More" : "hơn",
    "More apps menu" : "Nhiều trình đơn ứng dụng hơn",
    "Search" : "Tìm kiếm",
    "Reset search" : "Đặt lại tìm kiếm",
    "Contacts" : "Liên hệ",
    "Contacts menu" : "Trình đơn liên hệ",
    "Settings menu" : "Trình đơn thiết lập",
    "Confirm your password" : "Xác nhận mật khẩu của bạn",
    "Connect to your account" : "Kết nối tài khoản của bạn",
    "App token" : "Dấu hiệu ứng dụng",
    "Grant access" : "Cấp quyền truy cập",
    "Account access" : "Truy cập tài khoản",
    "The password is wrong. Try again." : "Sai mật khẩu. Hãy thử lại.",
    "Two-factor authentication" : "Xác thực 2 bước",
    "Use backup code" : "Sử dụng mã dự phòng",
    "Error while validating your second factor" : "Lỗi khi xác thực 2 bước",
    "Access through untrusted domain" : "Truy nhập thông qua tên miền không đáng tin",
    "Please contact your administrator. If you are an administrator, edit the \"trusted_domains\" setting in config/config.php like the example in config.sample.php." : "Xin vui lòng liên hệ với quản trị hệ thống của bạn. Nếu ban là người quản trị hệ thống, sửa phần thiết lập \"trusted_domains\" trong file config/config.php giống như trong ví dụ tại file config.sample.php.",
    "App update required" : "Ứng dụng yêu cầu cập nhật",
    "These apps will be updated:" : "Những ứng dụng sẽ được cập nhật:",
    "These incompatible apps will be disabled:" : "Những ứng dụng không tương thích sẽ bị tắt:",
    "The theme %s has been disabled." : "Giao diện %s đã bị tắt.",
    "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "Bạn cần phải bảo đảm rằng cơ sở dữ liệu, thư mục chứa file cấu hình hệ thống và thư mục chứa dữ liệu người dùng phải được sao lưu trước khi thực hiện.",
    "Start update" : "Bắt đầu cập nhật",
    "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "Để tránh thời gian quá hạn với các cài đặt lớn hơn, bạn có thể thực hiện chạy lệnh sau từ thư mục cài đặt:",
    "Detailed logs" : "Nhật ký chi tiết",
    "Update needed" : "Cần phải cập nhật",
    "Please use the command line updater because you have a big instance with more than 50 users." : "Xin vui lòng sử dụng lệnh cập nhật bằng dòng lệnh bởi vì bạn có một bản cài đặt lớn có hơn 50 người dùng.",
    "For help, see the  <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentation</a>." : "Trợ giúp, xem <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentation</a>.",
    "I know that if I continue doing the update via web UI has the risk, that the request runs into a timeout and could cause data loss, but I have a backup and know how to restore my instance in case of a failure." : "Tôi biết rằng nếu tôi tiếp tục thực hiện cập nhập qua giao diện Web có rủi ro, mà yêu cầu đó chạy trong một khoảng thời gian bị quá hạn và có thể gây mất dữ liệu, nếu tôi có một bản sao và tôi biết cách khôi phục bản cài đặt đã sao lưu trong trường hợp bị lỗi khi cập nhật.",
    "Upgrade via web on my own risk" : "Nâng cấp qua web",
    "This %s instance is currently in maintenance mode, which may take a while." : "Bản cài đặt%s hiện tại đang trong chế độ \"bảo trì\", do vậy có thể bạn cần phải đợi thêm chút ít thời gian.",
    "Contact your system administrator if this message persists or appeared unexpectedly." : "Liên hệ với người quản trị nếu lỗi này vẫn tồn tại hoặc xuất hiện bất ngờ.",
    "Could not send reset email because there is no email address for this username. Please contact your administrator." : "Không thể gửi thư điện tử yêu cầu thiết lập lại vì chưa có địa chỉ thư điện tử đối với tên đăng nhập này. Xin vui long liên hệ với quản trị hệ thống.",
    "Couldn't send reset email. Please make sure your username is correct." : "Không thể gửi thư điện tử yêu cầu thiết lập lại. Xin vui lòng kiểm tra tên tài khoản đăng nhập",
    "Dismiss" : "Bỏ qua",
    "The link to reset your password has been sent to your email. If you do not receive it within a reasonable amount of time, check your spam/junk folders.<br>If it is not there ask your local administrator." : "Liên kết để thiết lập lại mật khẩu của bạn vừa được gửi tới hộp thư điện tử của bạn. Nếu bạn không nhận được liên kết ấy trong vòng một khoảng thời gian xác định, xin vui long kiểm tra thư mục thư rác (spam/junk). <br> Nếu không nhận được thư có liên kết nói trên, xin vui lòng liên hệ quản trị hệ thống của bạn.",
    "Your files are encrypted. There will be no way to get your data back after your password is reset.<br />If you are not sure what to do, please contact your administrator before you continue. <br />Do you really want to continue?" : "Các file của bạn đã được mã hóa. Sẽ không có cách nào lấy lại dữ liệu của bạn sau khi mật khẩu được thiết lập lại. <br/> Nếu bạn không chắc điều gì sẽ xảy ra, xin vui lòng liên hệ người quản trị hệ thốngtrước khi bạn tiếp tục. <br/> Bạn có <b> thực sự muốn </b> tiếp tục?",
    "Sending email …" : "Đang gửi mail...",
    "Shared" : "Được chia sẻ",
    "Shared with" : "Chia sẽ với",
    "Shared by" : "Đã chia sẽ bởi",
    "Choose a password for the public link" : "Chọn mật khẩu cho liên kết công khai",
    "Choose a password for the public link or press the \"Enter\" key" : "Chọn một mật khẩu cho liên kết công cộng hoặc nhấn phím \"Enter\"",
    "Copied!" : "Được sao chép",
    "Copy link" : "Sao chép liên kết",
    "Not supported!" : "Không được hỗ trợ",
    "Press ⌘-C to copy." : "Nhất  ⌘-C để sao chép",
    "Press Ctrl-C to copy." : "Nhấn Ctrl-C để sao chép.",
    "Resharing is not allowed" : "Chia sẻ lại không được cho phép",
    "Link" : "Liên kết",
    "Password protect" : "Mật khẩu bảo vệ",
    "Allow editing" : "Cho phép điều chỉnh",
    "Email link to person" : "Liên kết email tới cá nhân",
    "Send" : "Gửi",
    "Allow upload and editing" : "Cho phép tải lên và chỉnh sửa",
    "Read only" : "Chỉ xem",
    "File drop (upload only)" : "Kéo thả file (chỉ áp dụng trong trường hợp tải lên)",
    "Set expiration date" : "Đặt ngày kết thúc",
    "Expiration" : "Hết hạn",
    "Expiration date" : "Ngày kết thúc",
    "Unshare" : "Bỏ chia sẻ",
    "Share to {name}" : "Chia sẻ với {name}",
    "Share link" : "Chia sẻ liên kết",
    "Password protect by Talk" : "Mật khẩu bảo vệ bằng đàm thoại",
    "Could not unshare" : "Không thể chia sẻ",
    "Shared with you and the group {group} by {owner}" : "Đã được chia sẽ với bạn và nhóm {group} bởi {owner}",
    "Shared with you by {owner}" : "Đã được chia sẽ bởi {owner}",
    "Choose a password for the mail share" : "Chọn một mật khẩu để chia sẻ qua mail",
    "group" : "nhóm",
    "remote" : "Từ xa",
    "email" : "Thư điện tử",
    "conversation" : "đàm thoại",
    "shared by {sharer}" : "được chia sẻ bởi {sharer}",
    "Can reshare" : "Có thể chia sẻ lại",
    "Can edit" : "Có thể chỉnh sửa",
    "Can create" : "Có thể tạo",
    "Can change" : "Có thể thay đổi",
    "Can delete" : "Có thể xóa",
    "Access control" : "Kiểm soát truy cập",
    "Error while sharing" : "Lỗi trong quá trình chia sẻ",
    "Share details could not be loaded for this item." : "Các chi tiết chia sẻ không thể được nạp đối với mục này",
    "_At least {count} character is needed for autocompletion_::_At least {count} characters are needed for autocompletion_" : ["Cần ít nhất {count} ký tự cho tự động hoàn thành"],
    "This list is maybe truncated - please refine your search term to see more results." : "Danh sách này có thể bị cắt ngắn - vui lòng chỉnh cụm từ tìm kiếm của bạn để thấy nhiều hơn kết quả khác.",
    "No users or groups found for {search}" : "Không có người dùng hoặc nhóm người dùng được tìm với từ khóa {search}",
    "No users found for {search}" : "Không tìm thấy người dùng cho {search}",
    "An error occurred (\"{message}\"). Please try again" : "Đã xảy ra lỗi (\"{message}\"). Hãy thử lại",
    "An error occurred. Please try again" : "Có lỗi vừa xảy ra. Xin vui lòng thử lại",
    "Home" : "Trang nhất",
    "Work" : "Công việc",
    "Other" : "Khác",
    "{sharee} ({type}, {owner})" : "{sharee} ({type}, {owner})",
    "Share" : "Chia sẻ",
    "Name or email address..." : "Tên hoặc địa chỉ email.",
    "Name or federated cloud ID..." : "Tên hoặc ID đám mây liên kết.",
    "Name, federated cloud ID or email address..." : "Tên người dùng, ID đám mây liên kết hoặc địa chỉ email.",
    "Name..." : "Tên người dùng...",
    "Error removing share" : "Lỗi khi xóa chia sẻ",
    "SQLite will be used as database." : "SQLite sẽ được sử dụng làm cơ sở dữ liệu.",
    "For larger installations we recommend to choose a different database backend." : "Đối với các cài đặt hệ thống lớn, chúng tôi khuyên bạn nên chọn một hệ cơ sở dữ liệu khác.",
    "Especially when using the desktop client for file syncing the use of SQLite is discouraged." : "Đặc biệt khi đang sử dụng phần mềm đồng bộ dữ liệu desktop client  để đồng bộ file thì việc sử dụng CSDL SQLite là không nên.",
    "Wrong password." : "Sai mật khẩu.",
    "New Password" : "Mật khẩu mới",
    "Cancel log in" : "Hủy đăng nhập"
},
"nplurals=1; plural=0;");
